SocketService class

Constructors

SocketService()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
messageStream Stream<Map<String, dynamic>>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String channelId, [String? firstMessage]) Future<void>
disconnect() → void
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage(String message, {String? type}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

baseWsUrl → const String